==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/de/dd9/graph__widget_8h.js <==
var graph__widget_8h =
[
    [ "CargoPaymentRatesWidgets", "de/dd9/graph__widget_8h.html#ac0f53ecbfd31aa30ae9308e7d72ffd88", [
      [ "WID_CPR_BACKGROUND", "de/dd9/graph__widget_8h.html#ac0f53ecbfd31aa30ae9308e7d72ffd88ad55741a09b51640e006f5f1994275e59", null ],
      [ "WID_CPR_HEADER", "de/dd9/graph__widget_8h.html#ac0f53ecbfd31aa30ae9308e7d72ffd88a14b0341d1690838ebbe9b9134f30c42d", null ],
      [ "WID_CPR_GRAPH", "de/dd9/graph__widget_8h.html#ac0f53ecbfd31aa30ae9308e7d72ffd88ab03a86af2e42e479ed068b0579a16e37", null ],
      [ "WID_CPR_RESIZE", "de/dd9/graph__widget_8h.html#ac0f53ecbfd31aa30ae9308e7d72ffd88a6df306c9222a4c5fad1eb9272b036928", null ],
      [ "WID_CPR_FOOTER", "de/dd9/graph__widget_8h.html#ac0f53ecbfd31aa30ae9308e7d72ffd88a6a331381486ba4d11306227b7d691173", null ],
      [ "WID_CPR_ENABLE_CARGOES", "de/dd9/graph__widget_8h.html#ac0f53ecbfd31aa30ae9308e7d72ffd88a46f4d1d708916458c7cf170fb6d39fe5", null ],
      [ "WID_CPR_DISABLE_CARGOES", "de/dd9/graph__widget_8h.html#ac0f53ecbfd31aa30ae9308e7d72ffd88ac14668664c0c9d916359554afe222bba", null ],
      [ "WID_CPR_CARGO_FIRST", "de/dd9/graph__widget_8h.html#ac0f53ecbfd31aa30ae9308e7d72ffd88a8cf44b22270be926c4fdf1d07ed6b3d0", null ]
    ] ],
    [ "CompanyLeagueWidgets", "de/dd9/graph__widget_8h.html#a6d664f75e95ed602d4827c6a85a6d698", [
      [ "WID_CL_BACKGROUND", "de/dd9/graph__widget_8h.html#a6d664f75e95ed602d4827c6a85a6d698a91456e2422a4580eba9fabff73dcb81e", null ]
    ] ],
    [ "CompanyValueWidgets", "de/dd9/graph__widget_8h.html#af87d46a888d1742cbe89909cfeb6071c", [
      [ "WID_CV_KEY_BUTTON", "de/dd9/graph__widget_8h.html#af87d46a888d1742cbe89909cfeb6071ca4ea0e39999f2fa40d36938cb20bfa7c0", null ],
      [ "WID_CV_BACKGROUND", "de/dd9/graph__widget_8h.html#af87d46a888d1742cbe89909cfeb6071ca44432474d2cff2c64f09ea6073c6b86b", null ],
      [ "WID_CV_GRAPH", "de/dd9/graph__widget_8h.html#af87d46a888d1742cbe89909cfeb6071ca1f21b839284c44f6c88ce74b5d024673", null ],
      [ "WID_CV_RESIZE", "de/dd9/graph__widget_8h.html#af87d46a888d1742cbe89909cfeb6071cae98bf4d8b4c8a3732d5b9c1e8cea92f9", null ]
    ] ],
    [ "GraphLegendWidgets", "de/dd9/graph__widget_8h.html#abe9bf569a08e1c6ed6d8f7ac518da8e9", [
      [ "WID_GL_BACKGROUND", "de/dd9/graph__widget_8h.html#abe9bf569a08e1c6ed6d8f7ac518da8e9aec1504788c76b3e7d62c5de8cc3ae11c", null ],
      [ "WID_GL_FIRST_COMPANY", "de/dd9/graph__widget_8h.html#abe9bf569a08e1c6ed6d8f7ac518da8e9a8b2eb52dbb82e677c49c84ec54fb5a5c", null ],
      [ "WID_GL_LAST_COMPANY", "de/dd9/graph__widget_8h.html#abe9bf569a08e1c6ed6d8f7ac518da8e9a9bcae84f42dc34c6d5a62301fd746c47", null ]
    ] ],
    [ "PerformanceHistoryGraphWidgets", "de/dd9/graph__widget_8h.html#a6d11527c70c96d4b285ebc7de6e3c869", [
      [ "WID_PHG_KEY", "de/dd9/graph__widget_8h.html#a6d11527c70c96d4b285ebc7de6e3c869a38a767b91162252ea790cb8de237d7c2", null ],
      [ "WID_PHG_DETAILED_PERFORMANCE", "de/dd9/graph__widget_8h.html#a6d11527c70c96d4b285ebc7de6e3c869a774ddf1861565b9c817cc00252e4ee10", null ],
      [ "WID_PHG_BACKGROUND", "de/dd9/graph__widget_8h.html#a6d11527c70c96d4b285ebc7de6e3c869a3ef97214125cb042f83b4036637e651b", null ],
      [ "WID_PHG_GRAPH", "de/dd9/graph__widget_8h.html#a6d11527c70c96d4b285ebc7de6e3c869ac60f490aa6f1e31c96edba37ef4b8244", null ],
      [ "WID_PHG_RESIZE", "de/dd9/graph__widget_8h.html#a6d11527c70c96d4b285ebc7de6e3c869a7bd8c223dfbe5fe5f38cf7b504e6a28b", null ]
    ] ],
    [ "PerformanceRatingDetailsWidgets", "de/dd9/graph__widget_8h.html#a398f2ae58aac5f90f4b17a6e92b3d71b", [
      [ "WID_PRD_SCORE_FIRST", "de/dd9/graph__widget_8h.html#a398f2ae58aac5f90f4b17a6e92b3d71baa531be6bf78d3bda78781fb93fb8895b", null ],
      [ "WID_PRD_SCORE_LAST", "de/dd9/graph__widget_8h.html#a398f2ae58aac5f90f4b17a6e92b3d71bac052b32a144bbfdc411c80a91c8a3369", null ],
      [ "WID_PRD_COMPANY_FIRST", "de/dd9/graph__widget_8h.html#a398f2ae58aac5f90f4b17a6e92b3d71ba615e22d2e7b775e25aee0427917228e3", null ],
      [ "WID_PRD_COMPANY_LAST", "de/dd9/graph__widget_8h.html#a398f2ae58aac5f90f4b17a6e92b3d71bae2ad12157bc72a8619d5516b94544564", null ]
    ] ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/de/dd9/graph__widget_8h.js <==
var graph__widget_8h =
[
    [ "CargoPaymentRatesWidgets", "de/dd9/graph__widget_8h.html#ac0f53ecbfd31aa30ae9308e7d72ffd88", [
      [ "WID_CPR_BACKGROUND", "de/dd9/graph__widget_8h.html#ac0f53ecbfd31aa30ae9308e7d72ffd88ad55741a09b51640e006f5f1994275e59", null ],
      [ "WID_CPR_HEADER", "de/dd9/graph__widget_8h.html#ac0f53ecbfd31aa30ae9308e7d72ffd88a14b0341d1690838ebbe9b9134f30c42d", null ],
      [ "WID_CPR_GRAPH", "de/dd9/graph__widget_8h.html#ac0f53ecbfd31aa30ae9308e7d72ffd88ab03a86af2e42e479ed068b0579a16e37", null ],
      [ "WID_CPR_RESIZE", "de/dd9/graph__widget_8h.html#ac0f53ecbfd31aa30ae9308e7d72ffd88a6df306c9222a4c5fad1eb9272b036928", null ],
      [ "WID_CPR_FOOTER", "de/dd9/graph__widget_8h.html#ac0f53ecbfd31aa30ae9308e7d72ffd88a6a331381486ba4d11306227b7d691173", null ],
      [ "WID_CPR_ENABLE_CARGOES", "de/dd9/graph__widget_8h.html#ac0f53ecbfd31aa30ae9308e7d72ffd88a46f4d1d708916458c7cf170fb6d39fe5", null ],
      [ "WID_CPR_DISABLE_CARGOES", "de/dd9/graph__widget_8h.html#ac0f53ecbfd31aa30ae9308e7d72ffd88ac14668664c0c9d916359554afe222bba", null ],
      [ "WID_CPR_MATRIX", "de/dd9/graph__widget_8h.html#ac0f53ecbfd31aa30ae9308e7d72ffd88ab9e582f0a0d1126b17d5ee4654545139", null ],
      [ "WID_CPR_MATRIX_SCROLLBAR", "de/dd9/graph__widget_8h.html#ac0f53ecbfd31aa30ae9308e7d72ffd88a762ab84d41f0d6104bd7310e89379cb2", null ]
    ] ],
    [ "CompanyLeagueWidgets", "de/dd9/graph__widget_8h.html#a6d664f75e95ed602d4827c6a85a6d698", [
      [ "WID_CL_BACKGROUND", "de/dd9/graph__widget_8h.html#a6d664f75e95ed602d4827c6a85a6d698a91456e2422a4580eba9fabff73dcb81e", null ]
    ] ],
    [ "CompanyValueWidgets", "de/dd9/graph__widget_8h.html#af87d46a888d1742cbe89909cfeb6071c", [
      [ "WID_CV_KEY_BUTTON", "de/dd9/graph__widget_8h.html#af87d46a888d1742cbe89909cfeb6071ca4ea0e39999f2fa40d36938cb20bfa7c0", null ],
      [ "WID_CV_BACKGROUND", "de/dd9/graph__widget_8h.html#af87d46a888d1742cbe89909cfeb6071ca44432474d2cff2c64f09ea6073c6b86b", null ],
      [ "WID_CV_GRAPH", "de/dd9/graph__widget_8h.html#af87d46a888d1742cbe89909cfeb6071ca1f21b839284c44f6c88ce74b5d024673", null ],
      [ "WID_CV_RESIZE", "de/dd9/graph__widget_8h.html#af87d46a888d1742cbe89909cfeb6071cae98bf4d8b4c8a3732d5b9c1e8cea92f9", null ]
    ] ],
    [ "GraphLegendWidgets", "de/dd9/graph__widget_8h.html#abe9bf569a08e1c6ed6d8f7ac518da8e9", [
      [ "WID_GL_BACKGROUND", "de/dd9/graph__widget_8h.html#abe9bf569a08e1c6ed6d8f7ac518da8e9aec1504788c76b3e7d62c5de8cc3ae11c", null ],
      [ "WID_GL_FIRST_COMPANY", "de/dd9/graph__widget_8h.html#abe9bf569a08e1c6ed6d8f7ac518da8e9a8b2eb52dbb82e677c49c84ec54fb5a5c", null ],
      [ "WID_GL_LAST_COMPANY", "de/dd9/graph__widget_8h.html#abe9bf569a08e1c6ed6d8f7ac518da8e9a9bcae84f42dc34c6d5a62301fd746c47", null ]
    ] ],
    [ "PerformanceHistoryGraphWidgets", "de/dd9/graph__widget_8h.html#a6d11527c70c96d4b285ebc7de6e3c869", [
      [ "WID_PHG_KEY", "de/dd9/graph__widget_8h.html#a6d11527c70c96d4b285ebc7de6e3c869a38a767b91162252ea790cb8de237d7c2", null ],
      [ "WID_PHG_DETAILED_PERFORMANCE", "de/dd9/graph__widget_8h.html#a6d11527c70c96d4b285ebc7de6e3c869a774ddf1861565b9c817cc00252e4ee10", null ],
      [ "WID_PHG_BACKGROUND", "de/dd9/graph__widget_8h.html#a6d11527c70c96d4b285ebc7de6e3c869a3ef97214125cb042f83b4036637e651b", null ],
      [ "WID_PHG_GRAPH", "de/dd9/graph__widget_8h.html#a6d11527c70c96d4b285ebc7de6e3c869ac60f490aa6f1e31c96edba37ef4b8244", null ],
      [ "WID_PHG_RESIZE", "de/dd9/graph__widget_8h.html#a6d11527c70c96d4b285ebc7de6e3c869a7bd8c223dfbe5fe5f38cf7b504e6a28b", null ]
    ] ],
    [ "PerformanceRatingDetailsWidgets", "de/dd9/graph__widget_8h.html#a398f2ae58aac5f90f4b17a6e92b3d71b", [
      [ "WID_PRD_SCORE_FIRST", "de/dd9/graph__widget_8h.html#a398f2ae58aac5f90f4b17a6e92b3d71baa531be6bf78d3bda78781fb93fb8895b", null ],
      [ "WID_PRD_SCORE_LAST", "de/dd9/graph__widget_8h.html#a398f2ae58aac5f90f4b17a6e92b3d71bac052b32a144bbfdc411c80a91c8a3369", null ],
      [ "WID_PRD_COMPANY_FIRST", "de/dd9/graph__widget_8h.html#a398f2ae58aac5f90f4b17a6e92b3d71ba615e22d2e7b775e25aee0427917228e3", null ],
      [ "WID_PRD_COMPANY_LAST", "de/dd9/graph__widget_8h.html#a398f2ae58aac5f90f4b17a6e92b3d71bae2ad12157bc72a8619d5516b94544564", null ]
    ] ]
];
